/*#############################################################
File Name       : ex1_TG12864H3_HelloWorld.c
Author          : Grant Phillips
Date Modified   : 03/10/2014
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F4-Discovery

Description     : Example program that writes "Hello World!" in
									normal mode and then inverted to a TG12864H3 
									graphics LCD.       

Requirements    : * STM32F4-Discovery Board
									* Make sure the TG12864H3_F4.c file is in the 
                    same folder than the project
									* If you want to use different pins for /CS,
										/RST, and A0, you need to define the SET and 
										RESET functions for the output port pins in 
										the TG12864H3_F4.c library and also do the 
										proper GPIO initialization for the output 
										port pins in TG12864H3_Init() in the
										TG12864H3_F4.c library.  SCLK and SID must 
										stay on PB13 and PB15.
              
Circuit         : * The TG12864H3 is connected as follows:
										(see the TG12864H3 datasheet for a complete
										description of each pin).
										/CS (TG12864H3 pin 1)		-	PD7
										/RST (TG12864H3 pin 2)	-	PE2
										A0 (pin3)								-	PD6
										SCLK (pin4)							-	PB13
										SID (pin5)							-	PB15
										VDD (pin6)							-	3V
										GND (pin7)							-	GND
										R- (pin8)								-	to GND if backlight must be RED
										A+ (pin9)								-	to 3V using a 100R resistor
										G- (pin10)							-	to GND if backlight must be GREEN
										B- (pin11)							-	to GND if backlight must be BLUE

See the STM32F4-Discovery User Manual (UM1472) for the block 
diagram of the STM32F407VGT6 processor (p12), a summary of
the GPIO connections (p20-29) and the schematic diagram (p31-36)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "STM32F4_Defaults.c"																		//library for the defaults of a blank project in Keil uVision
#include "TG12864H3_F4.c"																				//for the TG12864H3 graphics lcd functions on the STM32F4-Discovery

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/



int main(void)
{
	RCC_ClocksTypeDef 			RCC_Clocks;														//structure used for setting up the SysTick Interrupt
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										//will end up in this infinite loop if there was an error with Systick_Config
	
	TG12864H3_Init();												//initialize the lcd
	
	TG12864H3_PutStr("Hello World!", 1);		//print text in normal mode
	TG12864H3_PutStr("         ", 1);		  	//print 9 spaces in normal mode
	
	TG12864H3_PutStr("Hello World!", 0);		//print text in invert mode
	
	/* Main program loop */
  while (1)
  {
		//do nothing
  }	
}
