/*#############################################################
File Name       : ex2_TG12864H3_char_functions.c
Author          : Grant Phillips
Date Modified   : 03/10/2014
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F4-Discovery

Description     : Example program that demonstrates the use of
                  the character functions in the TG12864H3_F4.c
									library (TG12864H3_ClrScr(), TG12864H3_GotoXY(), 
									TG12864H3_PutChar(), TG12864H3_PutStr()) and 
                  the use of string function sprintf().      

Requirements    : * STM32F4-Discovery Board
									* Make sure the TG12864H3_F4.c file is in the 
                    same folder than the project
									* If you want to use different pins for /CS,
										/RST, and A0, you need to define the SET and 
										RESET functions for the output port pins in 
										the TG12864H3_F4.c library and also do the 
										proper GPIO initialization for the output 
										port pins in TG12864H3_Init() in the
										TG12864H3_F4.c library.  SCLK and SID must 
										stay on PB13 and PB15.
              
Circuit         : * The TG12864H3 is connected as described in
										ex1_TG12864H3_HelloWorld.c

See the STM32F4-Discovery User Manual (UM1472) for the block 
diagram of the STM32F407VGT6 processor (p12), a summary of
the GPIO connections (p20-29) and the schematic diagram (p31-36)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "STM32F4_Defaults.c"																		//library for the defaults of a blank project in Keil uVision
#include "TG12864H3_F4.c"																				//for the TG12864H3 graphics lcd functions on the STM32F4-Discovery

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/



int main(void)
{
	RCC_ClocksTypeDef 			RCC_Clocks;														//structure used for setting up the SysTick Interrupt
	
	char buf[21];                    				//declare a string variable of 21 chars   
  unsigned char i;
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										//will end up in this infinite loop if there was an error with Systick_Config
	
	TG12864H3_Init();												//initialize the lcd
		
	/* Main program loop */
  while (1)
  {
		TG12864H3_ClrScr(0);								  //clear the display and clear the dots (=0)
		Delay(1000);
		TG12864H3_GotoXY(0,0);								//set the character cursor to col=0, row=0
		TG12864H3_PutStr("Hello World!", 1);	//display text in normal mode
		Delay(500);
		
		TG12864H3_GotoXY(0,1);								//set the character cursor to col=0, row=1
		for(i=1;i<=10;i++)
    {
			sprintf(buf, "%d " , i);   					//print a integer value and space to the buf string
      TG12864H3_PutStr(buf,1);            //write a string variable to the LCD in normal mode
      Delay(500);
    }
		
		sprintf(buf, "Good Bye");  						//store a string constant into the buf string variable
    TG12864H3_GotoXY(0,2);								//set the character cursor to col=0, row=2 
    for(i=0;i<=7;i++)
    {
       TG12864H3_PutChar(buf[i], 1);      //display a character on the LCD in normal mode
       Delay(500);
    }
		
		TG12864H3_GotoXY(12,2);								//set the character cursor to col=12, row=2  
    for(i=65;i<=72;i++)
    {
      TG12864H3_PutChar(i, 1);  					//display a integer value as a byte onn the LCD in normal mode
																					//driver will convert it to the correpsonding ASCII char
      Delay(500);
    }
		
		// repeat, but clear LCD with black dots.  Print normal mode //
		TG12864H3_ClrScr(1);								  //clear the display and fill with dots (=1)
		Delay(1000);
		TG12864H3_GotoXY(0,0);								//set the character cursor to col=0, row=0
		TG12864H3_PutStr("Hello World!", 1);	//display text in normal mode
		Delay(500);
		
		TG12864H3_GotoXY(0,1);								//set the character cursor to col=0, row=1
		for(i=1;i<=10;i++)
    {
			sprintf(buf, "%d " , i);   					//print a integer value and space to the buf string
      TG12864H3_PutStr(buf,1);            //write a string variable to the LCD in normal mode
      Delay(500);
    }
		
		sprintf(buf, "Good Bye");  						//store a string constant into the buf string variable
    TG12864H3_GotoXY(0,2);								//set the character cursor to col=0, row=2 
    for(i=0;i<=7;i++)
    {
       TG12864H3_PutChar(buf[i], 1);      //display a character on the LCD in normal mode
       Delay(500);
    }
		
		TG12864H3_GotoXY(12,2);								//set the character cursor to col=12, row=2  
    for(i=65;i<=72;i++)
    {
      TG12864H3_PutChar(i, 1);  					//display a integer value as a byte onn the LCD in normal mode
																					//driver will convert it to the correpsonding ASCII char
      Delay(500);
    }
		
		// repeat, but clear LCD with clear dots.  Print inverted mode //
		TG12864H3_ClrScr(0);								  //clear the display and fill with clear dots (=0)
		Delay(1000);
		TG12864H3_GotoXY(0,0);								//set the character cursor to col=0, row=0
		TG12864H3_PutStr("Hello World!", 0);	//display text in inverted mode
		Delay(500);
		
		TG12864H3_GotoXY(0,1);								//set the character cursor to col=0, row=1
		for(i=1;i<=10;i++)
    {
			sprintf(buf, "%d " , i);   					//print a integer value and space to the buf string
      TG12864H3_PutStr(buf,0);            //write a string variable to the LCD in inverted mode
      Delay(500);
    }
		
		sprintf(buf, "Good Bye");  						//store a string constant into the buf string variable
    TG12864H3_GotoXY(0,2);								//set the character cursor to col=0, row=2 
    for(i=0;i<=7;i++)
    {
       TG12864H3_PutChar(buf[i], 0);      //display a character on the LCD in inverted mode
       Delay(500);
    }
		
		TG12864H3_GotoXY(12,2);								//set the character cursor to col=12, row=2  
    for(i=65;i<=72;i++)
    {
      TG12864H3_PutChar(i, 0);  					//display a integer value as a byte onn the LCD in inverted mode
																					//driver will convert it to the correpsonding ASCII char
      Delay(500);
    }
		
		// repeat, but clear LCD with black dots.  Print inverted mode //
		TG12864H3_ClrScr(1);								  //clear the display and fill with dots (=1)
		Delay(1000);
		TG12864H3_GotoXY(0,0);								//set the character cursor to col=0, row=0
		TG12864H3_PutStr("Hello World!", 0);	//display text in inverted mode
		Delay(500);
		
		TG12864H3_GotoXY(0,1);								//set the character cursor to col=0, row=1
		for(i=1;i<=10;i++)
    {
			sprintf(buf, "%d " , i);   					//print a integer value and space to the buf string
      TG12864H3_PutStr(buf,0);            //write a string variable to the LCD in inverted mode
      Delay(500);
    }
		
		sprintf(buf, "Good Bye");  						//store a string constant into the buf string variable
    TG12864H3_GotoXY(0,2);								//set the character cursor to col=0, row=2 
    for(i=0;i<=7;i++)
    {
       TG12864H3_PutChar(buf[i], 0);      //display a character on the LCD in inverted mode
       Delay(500);
    }
		
		TG12864H3_GotoXY(12,2);								//set the character cursor to col=12, row=2  
    for(i=65;i<=72;i++)
    {
      TG12864H3_PutChar(i, 0);  					//display a integer value as a byte onn the LCD in inverted mode
																					//driver will convert it to the correpsonding ASCII char
      Delay(500);
    }
  }	
}

