/*#############################################################
File Name       : ex4_TG12864H3_char_graphics.c
Author          : Grant Phillips
Date Modified   : 03/10/2014
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F4-Discovery

Description     : Example program that demonstrates the use of
                  the graphics functions combined with the 
									character functions.

Requirements    : * STM32F4-Discovery Board
									* Make sure the TG12864H3_F4.c file is in the 
                    same folder than the project
									* If you want to use different pins for /CS,
										/RST, and A0, you need to define the SET and 
										RESET functions for the output port pins in 
										the TG12864H3_F4.c library and also do the 
										proper GPIO initialization for the output 
										port pins in TG12864H3_Init() in the
										TG12864H3_F4.c library.  SCLK and SID must 
										stay on PB13 and PB15.
              
Circuit         : * The TG12864H3 is connected as described in
										ex1_TG12864H3_HelloWorld.c

See the STM32F4-Discovery User Manual (UM1472) for the block 
diagram of the STM32F407VGT6 processor (p12), a summary of
the GPIO connections (p20-29) and the schematic diagram (p31-36)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "STM32F4_Defaults.c"																		//library for the defaults of a blank project in Keil uVision
#include "TG12864H3_F4.c"																				//for the TG12864H3 graphics lcd functions on the STM32F4-Discovery

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/



int main(void)
{  
	RCC_ClocksTypeDef 			RCC_Clocks;														//structure used for setting up the SysTick Interrupt
	
  unsigned char i;
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										//will end up in this infinite loop if there was an error with Systick_Config
	
	TG12864H3_Init();												//initialize the lcd
		
	/* Main program loop */
  while (1)
  {
		TG12864H3_ClrScr(0);								  						//clear the display and clear the dots (=0)
		TG12864H3_GotoXY(1,3);
		TG12864H3_PutStr("Text under graphics", 1);				//print text before drawing graphics over it - normal mode
		TG12864H3_DrawLine(0,0,127,63,1);									//Draw a line from the top left corner to bottom right in color=1
		TG12864H3_DrawLine(0,0,0,63,1);										//Draw a line from the top left corner to bottom left in color=1
		TG12864H3_DrawLine(0,63,127,63,1);								//Draw a line from the bottom left corner to bottom right in color=1
		TG12864H3_DrawCircle(30,40,20,0,1);								//Draw a circle with radius=10, fill=0, color=1
		TG12864H3_DrawCircle(100,24,20,1,1);							//Draw a circle with radius=10, fill=0, color=1
		TG12864H3_DrawPixel(30,40,1);											//Draw a pixel in the left circle with color=1
		TG12864H3_GotoXY(1,4);
		TG12864H3_PutStr("Text over graphics", 1);				//print text over the graphics - normal mode
		for(i=0;i<10;i++)																	//Flash a pixel in the right circle 10 times by alternating the color between 0 and 1
		{
			TG12864H3_DrawPixel(100,24,0);									//Draw a pixel in the right circle with color=0
			Delay(200);
			TG12864H3_DrawPixel(100,24,1);									//Draw a pixel in the right circle with color=1
			Delay(200);
		}
		Delay(500);
		
		//repeat, but this time on a black background and clear foreground
		TG12864H3_ClrScr(1);								  						//clear the display and fill with dots (=1)
		TG12864H3_GotoXY(1,3);
		TG12864H3_PutStr("Text under graphics", 0);				//print text before drawing graphics over it - inverted mode
		TG12864H3_DrawLine(0,0,127,63,0);									//Draw a line from the top left corner to bottom right in color=0
		TG12864H3_DrawLine(0,0,0,63,0);										//Draw a line from the top left corner to bottom left in color=0
		TG12864H3_DrawLine(0,63,127,63,0);								//Draw a line from the bottom left corner to bottom right in color=0
		TG12864H3_DrawCircle(30,40,20,0,0);								//Draw a circle with radius=10, fill=0, color=0
		TG12864H3_DrawCircle(100,24,20,1,0);							//Draw a circle with radius=10, fill=0, color=0
		TG12864H3_DrawPixel(30,40,0);											//Draw a pixel in the left circle with color=0
		TG12864H3_GotoXY(1,4);
		TG12864H3_PutStr("Text over graphics", 0);				//print text over the graphics - inverted mode
		for(i=0;i<20;i++)																	//Flash a pixel in the right circle 10 times by alternating the color between 0 and 1
		{
			TG12864H3_DrawPixel(100,24,2);									//Draw a pixel in the right circle with color=2 (toggle color)
			Delay(200);
		}
		Delay(500);
  }	
}
