/*#############################################################
File Name       : ex5_TG12864H3_bounce.c
Author          : Grant Phillips
Date Modified   : 03/10/2014
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F4-Discovery

Description     : Example program that demonstrates a bouncing 
									ball on a graphics LCD.

Requirements    : * STM32F4-Discovery Board
									* Make sure the TG12864H3_F4.c file is in the 
                    same folder than the project
									* If you want to use different pins for /CS,
										/RST, and A0, you need to define the SET and 
										RESET functions for the output port pins in 
										the TG12864H3_F4.c library and also do the 
										proper GPIO initialization for the output 
										port pins in TG12864H3_Init() in the
										TG12864H3_F4.c library.  SCLK and SID must 
										stay on PB13 and PB15.
              
Circuit         : * The TG12864H3 is connected as described in
										ex1_TG12864H3_HelloWorld.c

See the STM32F4-Discovery User Manual (UM1472) for the block 
diagram of the STM32F407VGT6 processor (p12), a summary of
the GPIO connections (p20-29) and the schematic diagram (p31-36)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "STM32F4_Defaults.c"																		//library for the defaults of a blank project in Keil uVision
#include "TG12864H3_F4.c"																				//for the TG12864H3 graphics lcd functions on the STM32F4-Discovery

/* #defines --------------------------------------------------*/
#define BALL_RADIUS		10

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/



int main(void)
{  
	RCC_ClocksTypeDef 			RCC_Clocks;														//structure used for setting up the SysTick Interrupt
	
	uint8_t x = 64, y = 32;
	int8_t xdir= -1, ydir= -1;
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										//will end up in this infinite loop if there was an error with Systick_Config
	
	TG12864H3_Init();												//initialize the lcd
		
	TG12864H3_DrawCircle(x,y,BALL_RADIUS,1,1);
	Delay(1000);
	
	/* Main program loop */
  while (1)
  {
		/* delete the old ball by filling it with colour 0 at the old x and y position */
		TG12864H3_DrawCircle(x,y,BALL_RADIUS,1,0);		
		
		/* calculate the new x and y position */
		if(x == (0 + BALL_RADIUS))
			xdir = 1;
		if(x == (127 - BALL_RADIUS))
			xdir = -1;
		if(y == (0 + BALL_RADIUS))
			ydir = 1;
		if(y == (63 - BALL_RADIUS))
			ydir = -1;
		x = x + xdir;
		y = y + ydir;
		
		/* draw a new ball at the new x and y position */
		TG12864H3_DrawCircle(x,y,BALL_RADIUS,1,1);	
		
		/* delay to slow down the ball */
		Delay(50);
  }	
}
